@@ -4,8 +4,8 @@ from investing_algorithm_framework.core.exceptions import OperationalException
 from investing_algorithm_framework.core.identifier import Identifier
 from investing_algorithm_framework.core.market_identifier import \
     MarketIdentifier
-from investing_algorithm_framework.core.models import db, Portfolio, \
-    Position, Order, OrderStatus, OrderType, OrderSide
+from investing_algorithm_framework.core.models import db, SQLLitePortfolio, \
+    OrderStatus, OrderType, OrderSide, Portfolio, SQLLiteOrder, SQLLitePosition
 from investing_algorithm_framework.core.portfolio_managers.portfolio_manager\
     import PortfolioManager
 
@@ -37,7 +37,7 @@ class SQLLitePortfolioManager(PortfolioManager, Identifier, MarketIdentifier):
             if synced_unallocated is not None:
                 unallocated = synced_unallocated
 
-            portfolio = Portfolio(
+            portfolio = SQLLitePortfolio(
                 identifier=self.identifier,
                 trading_symbol=self.trading_symbol,
                 unallocated=unallocated,
@@ -65,7 +65,8 @@ class SQLLitePortfolioManager(PortfolioManager, Identifier, MarketIdentifier):
 
         if sync:
             synced_positions = self.get_positions_synced(algorithm_context)
-            positions = Position.query.filter_by(portfolio=self.get_portfolio())
+            positions = SQLLitePosition\
+                .query.filter_by(portfolio=self.get_portfolio())
 
             if synced_positions is not None:
                 for synced_position in synced_positions:
@@ -76,7 +77,9 @@ class SQLLitePortfolioManager(PortfolioManager, Identifier, MarketIdentifier):
 
                     if position is None:
 
-                        position = Position(symbol=synced_position["symbol"])
+                        position = SQLLitePosition(
+                            symbol=synced_position["symbol"]
+                        )
                         position.amount = synced_position["amount"]
                         position.portfolio = portfolio
                         db.session.commit()
@@ -87,7 +90,7 @@ class SQLLitePortfolioManager(PortfolioManager, Identifier, MarketIdentifier):
         return portfolio.unallocated
 
     def get_portfolio(self, throw_exception=True) -> Portfolio:
-        portfolio = Portfolio.query\
+        portfolio = SQLLitePortfolio.query\
             .filter_by(identifier=self.identifier)\
             .first()
 
@@ -99,10 +102,10 @@ class SQLLitePortfolioManager(PortfolioManager, Identifier, MarketIdentifier):
     def get_positions(self, symbol: str = None, lazy=False):
 
         if symbol is None:
-            query_set = Position.query \
+            query_set = SQLLitePosition.query \
                 .filter_by(portfolio=self.get_portfolio())
         else:
-            query_set = Position.query \
+            query_set = SQLLitePosition.query \
                 .filter_by(portfolio=self.get_portfolio()) \
                 .filter_by(symbol=symbol)
 
@@ -112,12 +115,12 @@ class SQLLitePortfolioManager(PortfolioManager, Identifier, MarketIdentifier):
             return query_set.all()
 
     def get_orders(self, symbol: str = None, status=None, lazy=False):
-        positions = Position.query \
+        positions = SQLLitePosition.query \
             .filter_by(portfolio=self.get_portfolio()) \
-            .with_entities(Position.id)
+            .with_entities(SQLLitePosition.id)
 
-        query_set = Order.query \
-            .filter(Order.position_id.in_(positions))
+        query_set = SQLLiteOrder.query \
+            .filter(SQLLiteOrder.position_id.in_(positions))
 
         if symbol is not None:
             query_set = query_set.filter_by(symbol=symbol)
